//
//  AVMetadataObject.swift
//  scanbot_sdk
//
//  Created by Zhenya Knizhnik on 26.08.19.
//

import Foundation
import AVFoundation

extension AVMetadataObject.ObjectType {
    static func fromArguments(_ arguments: [String: Any]) -> [AVMetadataObject.ObjectType]? {
        if let stringArray = arguments["barcodeFormats"] as? [String] {
            let barcodes = stringArray.compactMap({ AVMetadataObject.ObjectType(string: $0) })
            return barcodes
        }
        return nil
    }
    
    var stringName: String? {
        switch self {
        case .aztec: return "AZTEC"
        case .code39: return "CODE_39"
        case .code39Mod43: return "CODE_39"
        case .code93: return "CODE_93"
        case .code128: return "CODE_128"
        case .dataMatrix: return "DATA_MATRIX"
        case .ean8: return "EAN_8"
        case .ean13: return "EAN_13"
        case .interleaved2of5: return "ITF"
        case .itf14: return "ITF"
        case .pdf417: return "PDF_417"
        case .qr: return "QR_CODE"
        case .upce: return "UPC_E"
        default: return nil
        }
    }
    
    init?(string: String) {
        switch string {
        case "AZTEC": self = .aztec
        case "CODE_39": self = .code39
        case "CODE_93": self = .code93
        case "CODE_128": self = .code128
        case "DATA_MATRIX": self = .dataMatrix
        case "EAN_8": self = .ean8
        case "EAN_13": self = .ean13
        case "ITF": self = .interleaved2of5
        case "PDF_417": self = .pdf417
        case "QR_CODE": self = .qr
        case "UPC_E", "UPC_A": self = .upce
        case "UNKNOWN", "CODABAR", "MAXICODE", "RSS_14", "RSS_EXPANDED", "UPC_EAN_EXTENSION": return nil
        default: return nil
        }
    }
}
