//
//  BarcodeScannerPresenter.swift
//  scanbot_sdk
//
//  Created by Zhenya Knizhnik on 26.08.19.
//

import UIKit
import ScanbotSDK
import Flutter

class BarcodeScannerPresenter: NSObject {
    private var resultHandler: FlutterResult?
    private weak var presenter: UIViewController?

    func present(on presenter: UIViewController,
                 with configuration: SBSDKUIMachineCodeScannerConfiguration,
                 machineCodeTypes: [AVMetadataObject.ObjectType]?,
                 result: @escaping FlutterResult) {
        self.resultHandler = result
        self.presenter = presenter
        let controller = SBSDKUIBarcodeScannerViewController.createNew(withAcceptedMachineCodeTypes: machineCodeTypes,
                                                                       configuration: configuration,
                                                                       andDelegate: self)
        controller.modalPresentationStyle = .fullScreen
        presenter.present(controller, animated: true, completion: nil)
    }
}

extension BarcodeScannerPresenter: SBSDKUIBarcodeScannerViewControllerDelegate {
    func qrBarcodeDetectionViewController(_ viewController: SBSDKUIBarcodeScannerViewController, didDetect code: SBSDKMachineReadableCode) {
        viewController.isRecognitionEnabled = false;
        self.presenter?.dismiss(animated: true, completion: { [weak self] in
            let resultDict: [String: Any?] = [
                "text": code.stringValue,
                "barcodeFormat": code.metadata.codeObject.type.stringName
            ]
            self?.resultHandler?(resultDict.encodedString)
            self?.resultHandler = nil
            self?.presenter = nil
        })
    }
    
    func qrBarcodeDetectionViewControllerDidCancel(_ viewController: SBSDKUIBarcodeScannerViewController) {
        self.resultHandler = nil
        self.presenter = nil
    }
}
