import 'package:json_annotation/json_annotation.dart';

import 'common_data.dart';

part 'scanbot_sdk_models.g.dart';

/// Scanbot SDK initialization config parameters.
class ScanbotSdkConfig {
  /// Your license key for the Scanbot SDK.
  String licenseKey;

  /// Optional image quality value. Defines the quality factor of JPEG images.
  /// The value must be between 1 and 100, where 100 means maximum quality and
  /// largest file size. The default value is 80 which is a good compromise
  /// between image file size and document legibility.
  int imageQuality;

  /// Optional image format value in which format all pages will be stored.
  ImageFormat imageFormat;

  /// Optional logging flag. While it may be useful for development,
  /// consider switching logging OFF in production builds for security and performance reasons!
  bool loggingEnabled;

  /// Optional custom storage base directory. Can be nil.
  String storageBaseDirectory;

  ScanbotSdkConfig(
      {this.licenseKey,
      this.imageQuality,
      this.imageFormat,
      this.loggingEnabled,
      this.storageBaseDirectory});
}

/// Scanbot SDK license status.
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class SdkLicenseStatus {
  /// Indicates whether the current license key is valid or not.
  bool isLicenseValid;

  SdkLicenseStatus(this.isLicenseValid);

  factory SdkLicenseStatus.fromJson(Map<String, dynamic> json) =>
      _$SdkLicenseStatusFromJson(json);

  Map<String, dynamic> toJson() => _$SdkLicenseStatusToJson(this);
}
